@@ -1,4 +1,4 @@
-/* main.c - Last modified: 04-Mar-2020 (kobayasy)
+/* main.c - Last modified: 11-Mar-2020 (kobayasy)
  *
  * Copyright (c) 2018-2020 by Yuichi Kobayashi <kobayasy@kobayasy.com>
  *
@@ -40,7 +40,7 @@
 #include "psync_psp1.h"
 #include "popen3.h"
 
-#define VERSION "2.1"
+#define VERSION "2.2"
 #define CONFFILE ".psync.conf"
 
 #define ERROR_HELP    3
@@ -397,10 +397,21 @@ static int run(PSYNC_MODE mode, PSP *psp, bool verbose, char *hostname) {
         .psp = psp,
         .verbose = verbose
     };
-    char *const remote_args[] = {"ssh", "-qC", hostname, "psync", "--remote", 0};
+    char *remote_args[] = {"ssh", "-qCp", "22", hostname, "psync --remote", 0};
+    char **port = &remote_args[2];
+    char *s;
 
-    if (hostname != NULL)
+    if (hostname != NULL) {
+        s = strchr(hostname, '@');
+        if (s != NULL)
+            ++s;
+        else
+            s = hostname;
+        s = strrchr(s, '#');
+        if (s != NULL)
+            *s++ = 0, *port = s;
         status = popen3(remote_args, run_local, &param);
+    }
     else
         status = run_remote(STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO, 0, &param);
     return status;
@@ -599,14 +610,15 @@ error:
 static void usage(const char *argv0, FILE *fp) {
     fprintf(fp, "pSync version %s (protocol %c%c%c%u)\n"
                 "\n", VERSION, PSYNC_PROTID, PSYNC_PROTID >> 8, PSYNC_PROTID >> 16, PSYNC_PROTID >> 24 );
-    fprintf(fp, "Usage: %s [--sync] [-v|-q] [USER@]HOST\n"
-                "       %s --put [-v|-q] [USER@]HOST\n"
-                "       %s --get [-v|-q] [USER@]HOST\n"
+    fprintf(fp, "Usage: %s [--sync] [-v|-q] [USER@]HOST[#PORT]\n"
+                "       %s --put [-v|-q] [USER@]HOST[#PORT]\n"
+                "       %s --get [-v|-q] [USER@]HOST[#PORT]\n"
                 "       %s --help\n"
                 "\n", argv0, argv0, argv0, argv0 );
-    fputs("USER@HOST\n"
+    fputs("USER@HOST#PORT\n"
           "  HOST           hostname\n"
           "  USER           username (default: current login user)\n"
+          "  PORT           SSH port (default: 22)\n"
           "\n", fp );
     fputs("runmode\n"
           "  -s, --sync     synchronous mode (default)\n"
