@@ -1,4 +1,4 @@
-/* psync.c - Last modified: 27-Feb-2020 (kobayasy)
+/* psync.c - Last modified: 06-Mar-2020 (kobayasy)
  *
  * Copyright (c) 2018-2020 by Yuichi Kobayashi <kobayasy@kobayasy.com>
  *
@@ -712,8 +712,13 @@ static int make_fsynced_put_func(SETS sets, FLIST *flocal, FLIST *fremote, void
         LIST_INSERT_PREV(flocal, &priv->fsynced);
         break;
     case SETS_2NOT1:
+        fremote->st.flags |= FST_UPLD;
+        fremote->st.revision = priv->t;
+        fremote->st.mtime = 0;
+        fremote->st.mode = 0;
+        fremote->st.size = 0;
         LIST_DELETE(fremote);
-        free(fremote);
+        LIST_INSERT_PREV(fremote, &priv->fsynced);
         break;
     }
     status = 0;
@@ -721,7 +726,37 @@ static int make_fsynced_put_func(SETS sets, FLIST *flocal, FLIST *fremote, void
 }
 
 static int make_fsynced_get_func(SETS sets, FLIST *flocal, FLIST *fremote, void *data) {
-    return make_fsynced_put_func(sets, fremote, flocal, data);
+    int status = INT_MIN;
+    PRIV *priv = data;
+
+    switch (sets) {
+    case SETS_1AND2:
+        fremote->st.flags |= flocal->st.flags;
+        if (flocal->st.revision != fremote->st.revision &&
+            flocal->st.mtime != fremote->st.mtime )
+            fremote->st.flags |= FST_DNLD;
+        LIST_DELETE(flocal);
+        free(flocal);
+        LIST_DELETE(fremote);
+        LIST_INSERT_PREV(fremote, &priv->fsynced);
+        break;
+    case SETS_1NOT2:
+        flocal->st.flags |= FST_DNLD;
+        flocal->st.revision = priv->t;
+        flocal->st.mtime = 0;
+        flocal->st.mode = 0;
+        flocal->st.size = 0;
+        LIST_DELETE(flocal);
+        LIST_INSERT_PREV(flocal, &priv->fsynced);
+        break;
+    case SETS_2NOT1:
+        fremote->st.flags |= FST_DNLD;
+        LIST_DELETE(fremote);
+        LIST_INSERT_PREV(fremote, &priv->fsynced);
+        break;
+    }
+    status = 0;
+    return status;
 }
 
 static int preload(PRIV *priv) {
